package AccessCheck::App::Step1;

use Mojo::Base qw(AccessCheck::App::Controller);

use English qw(-no_match_vars);
use Syntax::Keyword::Try;

use AccessCheck::Data::Entity;

sub run {
    my $self = shift;

    my $app    = $self->app();
    my $config = $app->config();
    my $log    = $app->log();

    my $l10n = $self->init_l10n();
    my $user = $self->init_user();
    my $db   = $self->init_db();

    if ($config->{app}->{login_url}) {
        return if !$self->check_authentication();
    }

    my $sps = AccessCheck::Data::Entity->get_entities(
        db    => $db,
        query => [
            type => 'sp',
        ],
        sort_by => 'display_name'
    );

    my $idp;
    if ($user) {
        my $idps = AccessCheck::Data::Entity->get_entities(
            db    => $db,
            query => [
                type     => 'idp',
                entityid => $user->{idp}
            ]
        );
        $idp = $idps->[0];
    }

    $self->stash(sps => $sps);
    $self->stash(idp => $idp);

    $self->render(
        status   => 200,
        template => 'step1',
        format   => 'html'
    );
}

1;
