package AccessCheck::App::Step5;

use Mojo::Base qw(AccessCheck::App::Controller);

use DateTime;
use Email::MIME;
use Email::Sender::Simple;
use English qw(-no_match_vars);
use Syntax::Keyword::Try;
use Template::Constants qw(:chomp);

use AccessCheck::Data::Account;
use AccessCheck::Tools;

sub run {
    my $self = shift;

    my $app    = $self->app();
    my $config = $app->config();
    my $log    = $app->log();

    my $l10n = $self->init_l10n();
    my $user = $self->init_user();
    my $db   = $self->init_db();

    if ($config->{app}->{login_url}) {
        return if !$self->check_authentication();
    }

    my $entityid = $self->param('entityid');
    my $token    = $self->param('token');
    my $key      = $self->param('key');

    return if !$self->check_token(token => $token, entityid => $entityid);

    # load accounts from database
    my $accounts = AccessCheck::Data::Account->get_accounts(
        db    => $db,
        query => [
            token => $token
        ],
    );

    foreach my $account (@$accounts) {
        my $password = AccessCheck::Tools::decrypt(
            $account->password_crypt(), $key
        );
        $account->password($password);
    }

    $app->types()->type(csv => 'text/csv');

    $self->stash(accounts => $accounts);

    $self->render(
        status   => 200,
        template => 'accounts',
        format   => 'csv'
    );
}

1;
